Skip to contents

'biobakery_files' reads in the table extdata/biobakery_file_definitions.csv, which contains information about all available microbiome data types including their tool of origin, description, and units/normalization method.

Usage

biobakery_files()

Value

Tibble with columns 'data_type', 'tool', 'description', and 'units_normalization'

See also

Examples

biobakery_files()
#> # A tibble: 29 × 4
#>    data_type                       tool      description     units_normalization
#>    <chr>                           <chr>     <chr>           <chr>              
#>  1 genefamilies                    HUMAnN    Abundance of g… Reads Per Kilobase…
#>  2 genefamilies_cpm                HUMAnN    Gene family ab… Copies Per Million…
#>  3 genefamilies_cpm_stratified     HUMAnN    Gene family ab… Copies Per Million…
#>  4 genefamilies_cpm_unstratified   HUMAnN    Total communit… Copies Per Million…
#>  5 genefamilies_relab              HUMAnN    Gene family ab… Relative Abundance…
#>  6 genefamilies_relab_stratified   HUMAnN    Taxonomically … Relative Abundance…
#>  7 genefamilies_relab_unstratified HUMAnN    Total communit… Relative Abundance…
#>  8 genefamilies_stratified         HUMAnN    Raw gene famil… Reads Per Kilobase…
#>  9 genefamilies_unstratified       HUMAnN    Total communit… Reads Per Kilobase…
#> 10 marker_abundance                MetaPhlAn Abundance of c… Mean coverage of m…
#> # ℹ 19 more rows