Skip to contents

'get_ref_info' returns a table of information associated with each parquet reference file. The table can optionally be filtered by providing a column name to filter by and a string/regular expression to filter the selected column with.

Usage

get_ref_info(filter_col = NULL, filter_string = NULL)

Arguments

filter_col

Character string (optional): name of the column to filter by

filter_string

Character string (optional): string/regular expression to filter the selected column with.

Value

Data frame: A table of ref information, including information on general data types and tools served as well as descriptions.

See also

Examples

get_ref_info()
#>            ref_file                general_data_type      tool
#> 1    clade_name_ref               relative_abundance MetaPhlAn
#> 2   gene_family_ref                     genefamilies    HUMAnN
#> 3   genome_name_ref                   viral_clusters MetaPhlAn
#> 4       pathway_ref       pathabundance;pathcoverage    HUMAnN
#> 5 uniref_marker_ref marker_abundance;marker_presence MetaPhlAn
#>                                                                                                             description
#> 1      All unique values of clade_name and NCBI_tax_id found in the MetaPhlAn relative_abundance files in the same repo
#> 2                              All unique values of gene_family found in the HUMAnN genefamilies files in the same repo
#> 3                         All unique values of genome_name found in the MetaPhlAn viral_clusters files in the same repo
#> 4                All unique values of pathway found in the HUMAnN pathabundance and pathcoverage files in the same repo
#> 5 All unique values of uniref marker found in the MetaPhlAn marker_abundance and marker_presence files in the same repo