Skip to contents

'get_repo_info' returns a table of information associated with each Hugging Face repo that contains relevant parquet files.

Usage

get_repo_info()

Value

Data frame: A table of repo information, including information on overall organization, name, URL, and whether or not the repo is the selected default.

See also

Examples

get_repo_info()
#>                              repo_name
#> 1          waldronlab/metagenomics_mac
#> 2 waldronlab/metagenomics_mac_examples
#>                                                                         repo_url
#> 1          https://huggingface.co/datasets/waldronlab/metagenomics_mac/tree/main
#> 2 https://huggingface.co/datasets/waldronlab/metagenomics_mac_examples/tree/main
#>   default
#> 1       Y
#> 2       N